IdCard class

Inheritance

Constructors

IdCard()

Properties

hashCode int
The hash code for this object.
no setterinherited
images List<String>
no setteroverride
one String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
two String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
random() String
inherited
randomList({int count = 1}) List<String>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited